@@ -6,7 +6,7 @@
  *
  * @author      t.shirayanagi
  * @par         copyright
- * Copyright (C) 2011-2018, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2019, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -194,6 +194,9 @@ public:
     iuConcatParamHolder(const G1& g1, const G2& g2)
         : m_g1(g1), m_g2(g2) {}
 
+private:
+    iuConcatParamHolder() IUTEST_CXX_DELETED_FUNCTION;
+
 public:
     template<typename T>
     operator iuIParamGenerator<T>* ()
@@ -214,13 +217,15 @@ private:
     template<typename T>
     struct params_t
     {
+        typedef iuIParamGenerator<T> IParamGenerater;
         ::std::vector<T> val;
 
-        void append(iuIParamGenerator<T>* gen)
+        void append(IParamGenerater* gen)
         {
-            for( gen->Begin(); !gen->IsEnd(); gen->Next() )
+            detail::scoped_ptr<IParamGenerater> p(gen);
+            for( p->Begin(); !p->IsEnd(); p->Next() )
             {
-                val.push_back(gen->GetCurrent());
+                val.push_back(p->GetCurrent());
             }
         }
         template<typename U>
@@ -257,7 +262,7 @@ class iuValueArray
         explicit make_array(const _MyTuple& t)
         {
             tuples::tuple_foreach(t, *this);
-        };
+        }
     };
 public:
     explicit iuValueArray(const Args&... args)
@@ -544,7 +549,7 @@ public:
 #endif
 
 private:
-    void operator = (const _Myt&);
+    _Myt& operator = (const _Myt&) IUTEST_CXX_DELETED_FUNCTION;
 private:
     _MyTuple v;
 };
@@ -721,7 +726,7 @@ public:
     }
 
 private:
-    void operator = (const _Myt&) {}
+    _Myt& operator = (const _Myt&);
 private:
     const Generator1 m_g1;
     const Generator2 m_g2;
@@ -757,7 +762,7 @@ private:
                 IUTEST_PP_ENUM_BINARY(n, IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_STATICCAST_, T, m_g) );         \
         }                                                       \
         IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_CONCAT_()            \
-    private: void operator = (const _Myt&) {}                   \
+    private: _Myt& operator = (const _Myt&);                    \
         IUTEST_PP_REPEAT_BINARY(n, IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_VARIABLE_, const Generator, m_g)      \
     }
 
@@ -902,7 +907,7 @@ protected:
     }
 
     template<int N, typename Fn>
-    static int GetParamIndex(const ParamIndexes<N>& indexes, int raw, size_t count, Fn& func)
+    static int GetParamIndex(const ParamIndexes<N>& indexes, int raw, int count, Fn& func)
     {
         return indexes.index[raw] == -1 ? func(count)
             : indexes.index[raw];
@@ -911,7 +916,8 @@ protected:
     template<int N, typename T>
     static T GetParam(const ::std::vector<T>& params, const ParamIndexes<N>& indexes, int raw)
     {
-        const int index = GetParamIndex(indexes, raw, params.size(), TestEnv::genrand());
+        iuTypedRandom<int> rnd(TestEnv::genrand()());
+        const int index = GetParamIndex(indexes, raw, static_cast<int>(params.size()), rnd);
         return params[index];
     }
 
@@ -1108,7 +1114,7 @@ public:
 #endif
 
 private:
-    void operator = (const _Myt&);
+    _Myt& operator = (const _Myt&) IUTEST_CXX_DELETED_FUNCTION;
 private:
     _MyTuple v;
 };
@@ -1298,7 +1304,7 @@ public:
     }
 
 private:
-    void operator = (const _Myt&) {}
+    _Myt& operator = (const _Myt&);
 private:
     const Generator1 m_g1;
     const Generator2 m_g2;
@@ -1330,7 +1336,7 @@ private:
                 IUTEST_PP_ENUM_BINARY(n, IIUT_DECL_PAIRWISE_HOLDER_STATICCAST_, T, m_g) );          \
         }                                                       \
         IIUT_DECL_PAIRWISE_HOLDER_CONCAT_()                     \
-    private: void operator = (const _Myt&) {}                   \
+    private: _Myt& operator = (const _Myt&);                    \
         IUTEST_PP_REPEAT_BINARY(n, IIUT_DECL_PAIRWISE_HOLDER_VARIABLE_, const Generator, m_g)       \
     }
 
