@@ -6,7 +6,7 @@
  *
  * @author      t.shirayanagi
  * @par         copyright
- * Copyright (C) 2011-2018, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2019, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -20,6 +20,10 @@
 #include "../iutest_pred.hpp"
 #include "../iutest_package.hpp"
 
+#if defined(__clang_analyzer__)
+#  include <assert.h>
+#endif
+
 //======================================================================
 // define
 /**
@@ -48,7 +52,7 @@
 
 #define IIUT_ALIAS_TESTNAME_PP_UNPAREN_(...)    __VA_ARGS__
 
-#if defined(_MSC_VER)
+#if defined(_MSC_VER) && !defined(__clang__)
 #  define IUTEST_ALIAS_TESTNAME_(name_)         name_
 #  define IUTEST_ALIAS_TESTNAME_F_(name_, var_) UNPAREN_(dummy, var_, name_)
 #else
@@ -316,14 +320,14 @@
     IUTEST_AMBIGUOUS_ELSE_BLOCKER_                                          \
     if( const char* msg = "" ) {                                            \
         try {                                                               \
-            IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING(IIUT_SEH_THROUGH(statement));    \
+            IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING(IIUT_SEH_THROUGH(statement));  \
             msg = "\nExpected: " #statement " throws an exception of type " \
-                  #expected_exception ".\n  Actual: it throws nothing.";    \
+                #expected_exception ".\n  Actual: it throws nothing.";      \
             goto IUTEST_PP_CAT(iutest_label_throw, __LINE__);               \
         } catch( expected_exception const& ) {                              \
         } catch( ... ) {                                                    \
             msg = "\nExpected: " #statement " throws an exception of type " \
-          #expected_exception ".\n  Actual: it throws a different type.";   \
+                #expected_exception ".\n  Actual: it throws a different type.";     \
             goto IUTEST_PP_CAT(iutest_label_throw, __LINE__);               \
         }                                                                   \
     } else                                                                  \
@@ -360,10 +364,10 @@
 
 #define IUTEST_TEST_THROW_VALUE_EQ_(statement, expected_exception, expected_exception_value, on_failure)    \
     IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure            \
-        , ::iutest::internal::EqHelper<IUTEST_IS_NULLLITERAL(expected_exception_value)>::Compare)
+        , ::iutest::internal::backward::EqHelper<IUTEST_IS_NULLLITERAL(expected_exception_value)>::Compare)
 #define IUTEST_TEST_THROW_VALUE_NE_(statement, expected_exception, expected_exception_value, on_failure)    \
     IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure            \
-        , ::iutest::internal::NeHelper<IUTEST_IS_NULLLITERAL(expected_exception_value)>::Compare)
+        , ::iutest::internal::backward::NeHelper<IUTEST_IS_NULLLITERAL(expected_exception_value)>::Compare)
 #define IUTEST_TEST_THROW_VALUE_STREQ_(statement, expected_exception, expected_exception_value, on_failure) \
     IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure            \
         , ::iutest::internal::CmpHelperSTREQ)
@@ -457,12 +461,17 @@
  * @brief   IUTEST_ANALYSIS_ASSUME_ を通す
 */
 #if IUTEST_HAS_ANALYSIS_ASSUME
+#  define IUTEST_ANALYSIS_ASSUME_DELEGATE   IUTEST_ANALYSIS_ASSUME
+#elif defined(__clang_analyzer__)
+#  define IUTEST_ANALYSIS_ASSUME_DELEGATE   assert
+#endif
 
+#if defined(IUTEST_ANALYSIS_ASSUME_DELEGATE)
 #define IUTEST_THROUGH_ANALYSIS_ASSUME_(expr, todo)                 \
     IUTEST_AMBIGUOUS_ELSE_BLOCKER_                                  \
     if( bool b = true ) {                                           \
         IUTEST_UNUSED_VAR(b);                                       \
-        IUTEST_ANALYSIS_ASSUME(expr);                               \
+        IUTEST_ANALYSIS_ASSUME_DELEGATE(expr);                      \
         goto IUTEST_PP_CAT(iutest_label_analysis_assume, __LINE__); \
     } else                                                          \
         IUTEST_PP_CAT(iutest_label_analysis_assume, __LINE__):      \
@@ -480,11 +489,15 @@
  * @{
 */
 #define IUTEST_TEST_EQ(expected, actual, on_failure)        \
-    IUTEST_PRED_FORMAT2_( ::iutest::internal::EqHelper<IUTEST_IS_NULLLITERAL(expected)>::Compare    \
+    IUTEST_PRED_FORMAT2_( ::iutest::internal::backward::EqHelper<IUTEST_IS_NULLLITERAL(expected)>::Compare    \
+        , expected, actual, on_failure )
+
+#define IUTEST_TEST_ALMOST_EQ(expected, actual, on_failure)        \
+    IUTEST_PRED_FORMAT2_( ::iutest::internal::backward::AlmostEqHelper<IUTEST_IS_NULLLITERAL(expected)>::Compare    \
         , expected, actual, on_failure )
 
 #define IUTEST_TEST_NE(v1, v2, on_failure)                  \
-    IUTEST_PRED_FORMAT2_( ::iutest::internal::NeHelper<IUTEST_IS_NULLLITERAL(v1)>::Compare          \
+    IUTEST_PRED_FORMAT2_( ::iutest::internal::backward::NeHelper<IUTEST_IS_NULLLITERAL(v1)>::Compare          \
         , v1, v2, on_failure )
 
 #define IUTEST_TEST_LE(v1, v2, on_failure)                  \
@@ -595,12 +608,10 @@
         IUTEST_PP_CAT(iutest_label_test_no_fatalfailure_, __LINE__):        \
         on_failure("\nExpected: " #statement " doesn't generate new fatal failure.\n  Actual: it does.")
 
-#define IUTEST_TEST_SKIP()                                                          \
-    IUTEST_AMBIGUOUS_ELSE_BLOCKER_                                                  \
-    if( (::iutest::UnitTest::current_test_result()->Failed())                       \
-        || (::iutest::UnitTest::SkipTest(), ::iutest::detail::AlwaysTrue()) )       \
-        IUTEST_SKIP_MESSAGE( ::iutest::UnitTest::current_test_result()->Failed() ?  \
-             "Skipped. but already failed. " : "Skipped. " )
+#define IUTEST_TEST_SKIP()                  \
+    IUTEST_AMBIGUOUS_ELSE_BLOCKER_          \
+    if( ::iutest::detail::AlwaysTrue() )    \
+        IUTEST_SKIP_MESSAGE( ::iutest::UnitTest::SkipTest() ? "Skipped. " : "Skipped. but already failed. " )
 
 /**
  * @}
@@ -609,7 +620,7 @@
 /**
  * @brief   コンパイルエラーチェックタグ
 */
-#if defined(_MSC_VER)
+#if defined(_MSC_VER) && !defined(__clang__)
 #  define IUTEST_TEST_COMPILEERROR(e)   \
     IUTEST_PRAGMA_MESSAGE(__FILE__ "(" IUTEST_PP_TOSTRING(__LINE__) "): note : " "IUTEST_TEST_COMPILEERROR( " #e " )")
 #else
