@@ -6,7 +6,7 @@
  *
  * @author      t.shirayanagi
  * @par         copyright
- * Copyright (C) 2011-2017, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2019, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -202,8 +202,11 @@ public:
 
 public:
     /** @private */
-    class ScopedMessage : public detail::iu_list_node<ScopedMessage>
-        , public detail::iuCodeMessage
+    class ScopedMessage
+        : public detail::iuCodeMessage
+#if IUTEST_USE_OWN_LIST
+        , public detail::iu_list_node<ScopedMessage>
+#endif
     {
     public:
         ScopedMessage(const detail::iuCodeMessage& msg) // NOLINT
@@ -213,20 +216,24 @@ public:
         }
         ~ScopedMessage()
         {
-            ScopedTrace::GetInstance().list.erase(this);
+            ScopedTrace::GetInstance().list.remove(this);
         }
     };
 private:
     class ScopedTrace
     {
     public:
+#if IUTEST_USE_OWN_LIST
         typedef detail::iu_list<ScopedMessage> msg_list;
+#else
+        typedef ::std::list<ScopedMessage*> msg_list;
+#endif
         msg_list list;
         static ScopedTrace& GetInstance() { static ScopedTrace inst; return inst; }
     public:
         void append_message(TestPartResult& part_result)
         {
-            if( list.count() )
+            if( list.size() )
             {
                 part_result.add_message("\niutest trace:");
                 for( msg_list::iterator it = list.begin(), end=list.end(); it != end; ++it )
@@ -234,7 +241,7 @@ private:
                     // TODO : 追加メッセージとして保存するべき
                     // 現状はテスト結果のメッセージに追加している。
                     part_result.add_message("\n");
-                    part_result.add_message(it->make_message().c_str());
+                    part_result.add_message((*it)->make_message().c_str());
                 }
             }
         }
@@ -260,7 +267,7 @@ public:
             Message::operator << (val);
             return *this;
         }
-#if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
+#if IUTEST_HAS_IOMANIP
         Fixed& operator << (iu_basic_iomanip val)
         {
             Message::operator << (val);
@@ -325,7 +332,7 @@ private:
     void OnFixed(const Fixed& fixed)
     {
         // OnFixed で throw しないこと！テスト側の例外キャッチにかからなくなる
-        const std::string append_message = fixed.GetString();
+        const ::std::string append_message = fixed.GetString();
         if( !append_message.empty() )
         {
             m_part_result.add_message(" " + append_message);
@@ -417,7 +424,7 @@ inline ::std::string GetBooleanAssertionFailureMessage(const AssertionResult& ar
  * @brief   Eq 系アサーション
 */
 inline AssertionResult EqFailure(const char* expected_expression, const char* actual_expression
-    , const std::string& expected, const std::string& actual, bool ignoring_case = false)
+    , const ::std::string& expected, const ::std::string& actual, bool ignoring_case = false)
 {
     iu_global_format_stringstream strm;
     strm << "error: Value of " << actual_expression
@@ -475,8 +482,8 @@ IIUT_DECL_COMPARE_HELPER_(LT, < )
 IIUT_DECL_COMPARE_HELPER_(GE, >=)
 IIUT_DECL_COMPARE_HELPER_(GT, > )
 
-#undef DECL_COMPARE_HELPER_I_
-#undef DECL_COMPARE_HELPER_
+#undef IIUT_DECL_COMPARE_HELPER_I_
+#undef IIUT_DECL_COMPARE_HELPER_
 
 /**
  * @}
@@ -535,7 +542,7 @@ public:
 
 template<typename T1, typename T2>
 inline AssertionResult CmpHelperSame(const char* expected_str, const char* actual_str
-                                      , const T1& expected, const T2& actual)
+                                    , const T1& expected, const T2& actual)
 {
     if( &expected == &actual )
     {
@@ -609,6 +616,44 @@ IUTEST_PRAGMA_WARN_DISABLE_SIGN_COMPARE()
 IUTEST_PRAGMA_WARN_POP()
 }
 
+template<typename RawType>
+inline AssertionResult CmpHelperFloatingPointEQ(const char* expr1, const char* expr2
+                                                , RawType val1, RawType val2)
+{
+    floating_point<RawType> f1(val1), f2(val2);
+    if( f1.AlmostEquals(f2) )
+    {
+        return AssertionSuccess();
+    }
+    return EqFailure(expr1, expr2
+        , detail::ShowStringQuoted(FormatForComparisonFailureMessage(f1, f2))
+        , detail::ShowStringQuoted(FormatForComparisonFailureMessage(f2, f1)));
+}
+
+template<typename RawType>
+inline AssertionResult CmpHelperFloatingPointLE(const char* expr1, const char* expr2
+                                                , RawType val1, RawType val2)
+{
+    if( val1 < val2 )
+    {
+        return AssertionSuccess();
+    }
+    floating_point<RawType> f1(val1), f2(val2);
+    if( f1.AlmostEquals(f2) )
+    {
+        return AssertionSuccess();
+    }
+    return EqFailure(expr1, expr2
+        , detail::ShowStringQuoted(FormatForComparisonFailureMessage(f1, f2))
+        , detail::ShowStringQuoted(FormatForComparisonFailureMessage(f2, f1)));
+}
+
+/**
+ * @brief   backward
+*/
+namespace backward
+{
+
 /**
  * @brief   Equal Helper
  * @tparam  IsNullLiteral   = val1 が NULL リテラルかどうか
@@ -640,7 +685,6 @@ public:
     {
         return CmpHelper<T, detail::has_equal_to<T>::value>::Compare(expr1, expr2, val1, val2);
     }
-
 #endif
 
 public:
@@ -676,11 +720,44 @@ public:
     template<typename T1, typename T2>
     static AssertionResult Compare(const char* expr1, const char* expr2, const T1& val1, const T2& val2)
     {
-        return CmpHelperEQ(expr1, expr2, (T2)val1, val2);
+        return CmpHelperEQ(expr1, expr2, (T2)(val1), val2); // NOLINT
     }
 #endif
 };
 
+/**
+ * @brief   Almost Equal Helper
+ * @tparam  IsNullLiteral   = val1 が NULL リテラルかどうか
+*/
+template<bool IsNullLiteral>
+class AlmostEqHelper : public EqHelper<false>
+{
+public:
+    template<typename T1, typename T2>
+    static AssertionResult Compare(const char* expr1, const char* expr2, const T1& val1, const T2& val2)
+    {
+        return EqHelper<false>::Compare(expr1, expr2, val1, static_cast<T1>(val2));
+    }
+    template<typename T>
+    static AssertionResult Compare(const char* expr1, const char* expr2, const float& val1, const T& val2)
+    {
+        return CmpHelperFloatingPointEQ<float>(expr1, expr2, val1, static_cast<float>(val2));
+    }
+    template<typename T>
+    static AssertionResult Compare(const char* expr1, const char* expr2, const double& val1, const T& val2)
+    {
+        return CmpHelperFloatingPointEQ<double>(expr1, expr2, val1, static_cast<double>(val2));
+    }
+};
+
+/**
+ * @brief   EqHelper 特殊化
+*/
+template<>
+class AlmostEqHelper<true> : public EqHelper<true>
+{
+};
+
 /**
  * @brief   Not Equal Helper
  * @tparam  IsNullLiteral   = val1 が NULL リテラルかどうか
@@ -748,15 +825,63 @@ public:
     template<typename T1, typename T2>
     static AssertionResult Compare(const char* expr1, const char* expr2, const T1& val1, const T2& val2)
     {
-        return CmpHelperNE(expr1, expr2, (T2)val1, val2);
+        return CmpHelperNE(expr1, expr2, (T2)(val1), val2); // NOLINT
     }
 #endif
 };
 
+}   // end of namespace backward
+
+#if IUTEST_HAS_NULLPTR && IUTEST_HAS_CXX_HDR_TYPE_TARITS && 0
+
+/**
+ * @brief   Equal Helper
+*/
+class EqHelper
+{
+    template<typename T1, typename T2, typename detail::enable_if<
+        !detail::is_integral<T1>::value || !detail::is_pointer<T2>::value, void>::type*& = detail::enabler::value>
+    static AssertionResult Compare(const char* expr1, const char* expr2, const T1& val1, const T2& val2)
+    {
+        return backward::EqHelper<false>::Compare(expr1, expr2, val1, val2);
+    }
+    template<typename T>
+    static AssertionResult Compare(const char* expr1, const char* expr2, ::std::nullptr_t, T* val2)
+    {
+        return CmpHelperEQ(expr1, expr2, static_cast<T*>(NULL), val2);
+    }
+};
+
+/**
+ * @brief   Not Equal Helper
+*/
+class NeHelper
+{
+    template<typename T1, typename T2, typename detail::enable_if<
+        !detail::is_integral<T1>::value || !detail::is_pointer<T2>::value, void>::type*& = detail::enabler::value>
+    static AssertionResult Compare(const char* expr1, const char* expr2, const T1& val1, const T2& val2)
+    {
+        return backward::NeHelper<false>::Compare(expr1, expr2, val1, val2);
+    }
+    template<typename T>
+    static AssertionResult Compare(const char* expr1, const char* expr2, ::std::nullptr_t, T* val2)
+    {
+        return CmpHelperNE(expr1, expr2, static_cast<T*>(NULL), val2);
+    }
+};
+
+#else
+
+using backward::EqHelper;
+using backward::AlmostEqHelper;
+using backward::NeHelper;
+
+#endif
+
 template<typename RawType>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNearFloatingPoint(
-      const char* expr1, const char* expr2, const char* absc
-    , RawType val1, RawType val2, RawType abs_v)
+    const char* expr1, const char* expr2, const char* absc
+        , RawType val1, RawType val2, RawType abs_v)
 {
     RawType diff = val1 > val2 ? val1 - val2 : val2 - val1;
     if( diff < abs_v )
@@ -773,16 +898,16 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNearFloatingPoint(
         << "\nExpected: " << FormatForComparisonFailureMessage(abs_v, diff);
 }
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ DoubleNearPredFormat(
-      const char* expr1, const char* expr2, const char* absc
-    , double val1, double val2, double abs_v)
+    const char* expr1, const char* expr2, const char* absc
+        , double val1, double val2, double abs_v)
 {
     return CmpHelperNearFloatingPoint(expr1, expr2, absc, val1, val2, abs_v);
 }
 #if !defined(IUTEST_NO_FUNCTION_TEMPLATE_ORDERING)
 template<typename T, typename A>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNear(
-      const char* expr1, const char* expr2, const char* absc
-    , const T& val1, const T& val2, const A& abs_v)
+    const char* expr1, const char* expr2, const char* absc
+        , const T& val1, const T& val2, const A& abs_v)
 {
     T diff = val1 > val2 ? val1 - val2 : val2 - val1;
     if( diff <= abs_v )
@@ -795,16 +920,16 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNear(
 }
 template<typename A>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNear(
-      const char* expr1, const char* expr2, const char* absc
-    , double val1, double val2, const A& abs_v)
+    const char* expr1, const char* expr2, const char* absc
+        , double val1, double val2, const A& abs_v)
 {
     return CmpHelperNearFloatingPoint<double>(expr1, expr2, absc, val1, val2, static_cast<double>(abs_v));
 }
 #endif
 template<typename A>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNear(
-      const char* expr1, const char* expr2, const char* absc
-    , float val1, float val2, const A& abs_v)
+    const char* expr1, const char* expr2, const char* absc
+        , float val1, float val2, const A& abs_v)
 {
     return CmpHelperNearFloatingPoint<float>(expr1, expr2, absc, val1, val2, static_cast<float>(abs_v));
 }
@@ -813,70 +938,51 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNear(
 namespace StrEqHelper
 {
 
-inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const char* val1, const char* val2)
-{
-    if( val1 == NULL || val2 == NULL )
-    {
-        return val1 == val2;
+#if IUTEST_HAS_NULLPTR && 0
+#define IIUT_DECL_STREQ_COMPARE_HELPER_NULL_(T)   \
+    inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(::std::nullptr_t, const T* val2) {     \
+        return val2 == NULL;                                                            \
     }
-    return strcmp(val1, val2) == 0;
-}
+#else
+#define IIUT_DECL_STREQ_COMPARE_HELPER_NULL_(T)
+#endif
 
-inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const wchar_t* val1, const wchar_t* val2)
-{
-    if( val1 == NULL || val2 == NULL )
-    {
-        return val1 == val2;
+#define IIUT_DECL_STREQ_COMPARE_HELPER_SV_(T)   \
+    inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(detail::iu_nullable_basic_string_view<T> val1  \
+        , detail::iu_nullable_basic_string_view<T> val2) {                                      \
+        return val1 == val2;                                                                    \
+    }                                                                                           \
+    inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const T* val1, const T* val2) {                \
+        if( val1 == NULL || val2 == NULL ) { return val1 == val2; }                             \
+        return Compare(detail::iu_nullable_basic_string_view<T>(val1)                           \
+            , detail::iu_nullable_basic_string_view<T>(val2));                                  \
     }
-    return wcscmp(val1, val2) == 0;
-}
 
-template<typename Elem, typename Traits, typename Ax>
-inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const ::std::basic_string<Elem, Traits, Ax>& val1
-    , const ::std::basic_string<Elem, Traits, Ax>& val2)
-{
-    return val1 == val2;
-}
-template<typename Elem, typename Traits, typename Ax>
-inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const Elem* val1
-    , const ::std::basic_string<Elem, Traits, Ax>& val2)
-{
-    return val2 == val1;
-}
-template<typename Elem, typename Traits, typename Ax>
-inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const ::std::basic_string<Elem, Traits, Ax>& val1
-    , const Elem* val2)
-{
-    return val1 == val2;
-}
+#define IIUT_DECL_STREQ_COMPARE_HELPER_(T)      \
+    IIUT_DECL_STREQ_COMPARE_HELPER_SV_(T)       \
+    IIUT_DECL_STREQ_COMPARE_HELPER_NULL_(T)
+
+IIUT_DECL_STREQ_COMPARE_HELPER_(char)
+IIUT_DECL_STREQ_COMPARE_HELPER_(wchar_t)
 #if IUTEST_HAS_CHAR16_T
-inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const char16_t* val1, const char16_t* val2)
-{
-    if( val1 == NULL || val2 == NULL )
-    {
-        return val1 == val2;
-    }
-    ::std::u16string v1 = val1;
-    return Compare(v1, val2);
-}
+IIUT_DECL_STREQ_COMPARE_HELPER_(char16_t)
 #endif
 #if IUTEST_HAS_CHAR32_T
-inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const char32_t* val1, const char32_t* val2)
-{
-    if( val1 == NULL || val2 == NULL )
-    {
-        return val1 == val2;
-    }
-    ::std::u32string v1 = val1;
-    return Compare(v1, val2);
-}
+IIUT_DECL_STREQ_COMPARE_HELPER_(char32_t)
 #endif
 
+#undef IIUT_DECL_STREQ_COMPARE_HELPER_
+#undef IIUT_DECL_STREQ_COMPARE_HELPER_SV_
+
+}   // end of namespace StrEqHelper
+
 template<typename T1, typename T2>
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ Assertion(const char* expr1, const char* expr2
-    , const T1& val1, const T2& val2)
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(
+    const char* expr1, const char* expr2
+    , T1 val1, T2 val2, typename detail::enable_if<
+        !detail::is_integral<T1>::value || !detail::is_pointer<T2>::value, void>::type*& = detail::enabler::value)
 {
-    if( Compare(val1, val2) )
+    if( StrEqHelper::Compare(val1, val2) )
     {
         return AssertionSuccess();
     }
@@ -886,55 +992,21 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ Assertion(const char* expr1, con
         , detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1)));
 }
 
-}   // end of namespace StrEqHelper
+template<typename T>
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(
+    const char* expr1, const char* expr2
+    , detail::iu_nullptr_convertible_t, T val2)
+{
+    if( StrEqHelper::Compare(IUTEST_NULLPTR, val2) )
+    {
+        return AssertionSuccess();
+    }
 
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
-                               , const char* val1, const char* val2)
-{
-    return StrEqHelper::Assertion(expr1, expr2, val1, val2);
+    return EqFailure(expr1, expr2
+        , detail::ShowStringQuoted(FormatForComparisonFailureMessage(IUTEST_NULLPTR, val2))
+        , detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, IUTEST_NULLPTR)));
 }
 
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
-                               , const wchar_t* val1, const wchar_t* val2)
-{
-    return StrEqHelper::Assertion(expr1, expr2, val1, val2);
-}
-template<typename Elem, typename Traits, typename Ax>
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
-                                                                , const ::std::basic_string<Elem, Traits, Ax>& val1
-                                                                , const ::std::basic_string<Elem, Traits, Ax>& val2)
-{
-    return StrEqHelper::Assertion(expr1, expr2, val1, val2);
-}
-template<typename Elem, typename Traits, typename Ax>
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
-                                                                , const Elem* val1
-                                                                , const ::std::basic_string<Elem, Traits, Ax>& val2)
-{
-    return StrEqHelper::Assertion(expr1, expr2, val1, val2);
-}
-template<typename Elem, typename Traits, typename Ax>
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
-                                                                , const ::std::basic_string<Elem, Traits, Ax>& val1
-                                                                , const Elem* val2)
-{
-    return StrEqHelper::Assertion(expr1, expr2, val1, val2);
-}
-#if IUTEST_HAS_CHAR16_T
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
-                                                            , const char16_t* val1, const char16_t* val2)
-{
-    return StrEqHelper::Assertion(expr1, expr2, val1, val2);
-}
-#endif
-#if IUTEST_HAS_CHAR32_T
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
-                                                            , const char32_t* val1, const char32_t* val2)
-{
-    return StrEqHelper::Assertion(expr1, expr2, val1, val2);
-}
-#endif
-
 namespace StrNeHelper
 {
 
@@ -944,11 +1016,16 @@ inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const T1& val1, const T2& val2)
     return !StrEqHelper::Compare(val1, val2);
 }
 
+}   // end of namespace StrNeHelper
+
 template<typename T1, typename T2>
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ Assertion(const char* expr1, const char* expr2
-    , const T1& val1, const T2& val2)
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(
+    const char* expr1, const char* expr2
+    , T1 val1, T2 val2, typename detail::enable_if<
+        ((!detail::is_integral<T2>::value || !detail::is_pointer<T1>::value) &&
+        (!detail::is_integral<T1>::value || !detail::is_pointer<T2>::value)), void>::type*& = detail::enabler::value)
 {
-    if( Compare(val1, val2) )
+    if( StrNeHelper::Compare(val1, val2) )
     {
         return AssertionSuccess();
     }
@@ -958,53 +1035,35 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ Assertion(const char* expr1, con
         << " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
 }
 
-}   // end of namespace StrNeHelper
+template<typename T>
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(
+    const char* expr1, const char* expr2
+    , detail::iu_nullptr_convertible_t, T val2)
+{
+    if( !StrEqHelper::Compare(IUTEST_NULLPTR, val2) )
+    {
+        return AssertionSuccess();
+    }
 
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
-                            , const char* val1, const char* val2)
-{
-    return StrNeHelper::Assertion(expr1, expr2, val1, val2);
+    return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2
+        << "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, IUTEST_NULLPTR))
+        << " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(IUTEST_NULLPTR, val2));
 }
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
-                            , const wchar_t* val1, const wchar_t* val2)
+
+template<typename T>
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(
+    const char* expr1, const char* expr2
+    , T val1, detail::iu_nullptr_convertible_t)
 {
-    return StrNeHelper::Assertion(expr1, expr2, val1, val2);
+    if( !StrEqHelper::Compare(val1, IUTEST_NULLPTR) )
+    {
+        return AssertionSuccess();
+    }
+
+    return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2
+        << "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(IUTEST_NULLPTR, val1))
+        << " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, IUTEST_NULLPTR));
 }
-template<typename Elem, typename Traits, typename Ax>
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
-                                                            , const ::std::basic_string<Elem, Traits, Ax>& val1
-                                                            , const ::std::basic_string<Elem, Traits, Ax>& val2)
-{
-    return StrNeHelper::Assertion(expr1, expr2, val1, val2);
-}
-template<typename Elem, typename Traits, typename Ax>
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
-                                                            , const Elem* val1
-                                                            , const ::std::basic_string<Elem, Traits, Ax>& val2)
-{
-    return StrNeHelper::Assertion(expr1, expr2, val1, val2);
-}
-template<typename Elem, typename Traits, typename Ax>
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
-                                                            , const ::std::basic_string<Elem, Traits, Ax>& val1
-                                                            , const Elem* val2)
-{
-    return StrNeHelper::Assertion(expr1, expr2, val1, val2);
-}
-#if IUTEST_HAS_CHAR16_T
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
-                                                            , const char16_t* val1, const char16_t* val2)
-{
-    return StrNeHelper::Assertion(expr1, expr2, val1, val2);
-}
-#endif
-#if IUTEST_HAS_CHAR32_T
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
-                                                            , const char32_t* val1, const char32_t* val2)
-{
-    return StrNeHelper::Assertion(expr1, expr2, val1, val2);
-}
-#endif
 
 namespace StrCaseEqHelper
 {
@@ -1028,27 +1087,31 @@ inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const wchar_t* val1, const wchar_t*
 }
 
 template<typename Elem, typename Traits, typename Ax>
-inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const ::std::basic_string<Elem, Traits, Ax>& val1
-    , const ::std::basic_string<Elem, Traits, Ax>& val2)
+inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(
+    const ::std::basic_string<Elem, Traits, Ax>& val1
+        , const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
     return Compare(val1.c_str(), val2.c_str());
 }
 template<typename Elem, typename Traits, typename Ax>
-inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const Elem* val1
-    , const ::std::basic_string<Elem, Traits, Ax>& val2)
+inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(
+    const Elem* val1
+        , const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
     return Compare(val1, val2.c_str());
 }
 template<typename Elem, typename Traits, typename Ax>
-inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const ::std::basic_string<Elem, Traits, Ax>& val1
-    , const Elem* val2)
+inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(
+    const ::std::basic_string<Elem, Traits, Ax>& val1
+        , const Elem* val2)
 {
     return Compare(val1.c_str(), val2);
 }
 
 template<typename T1, typename T2>
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ Assertion(const char* expr1, const char* expr2
-    , const T1& val1, const T2& val2)
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ Assertion(
+    const char* expr1, const char* expr2
+        , const T1& val1, const T2& val2)
 {
     if( Compare(val1, val2) )
     {
@@ -1063,31 +1126,37 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ Assertion(const char* expr1, con
 
 }   // end of namespace StrCaseEqHelper
 
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(const char* expr1, const char* expr2
-                            , const char* val1, const char* val2)
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(
+    const char* expr1, const char* expr2
+        , const char* val1, const char* val2)
 {
     return StrCaseEqHelper::Assertion(expr1, expr2, val1, val2);
 }
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(const char* expr1, const char* expr2
-                            , const wchar_t* val1, const wchar_t* val2)
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(
+    const char* expr1, const char* expr2
+        , const wchar_t* val1, const wchar_t* val2)
 {
     return StrCaseEqHelper::Assertion(expr1, expr2, val1, val2);
 }
 template<typename Elem, typename Traits, typename Ax>
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(const char* expr1, const char* expr2
-    , const ::std::basic_string<Elem, Traits, Ax>& val1, const ::std::basic_string<Elem, Traits, Ax>& val2)
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(
+    const char* expr1, const char* expr2
+        , const ::std::basic_string<Elem, Traits, Ax>& val1
+        , const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
     return CmpHelperSTRCASEEQ(expr1, expr2, val1.c_str(), val2.c_str());
 }
 template<typename Elem, typename Traits, typename Ax>
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(const char* expr1, const char* expr2
-    , const Elem* val1, const ::std::basic_string<Elem, Traits, Ax>& val2)
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(
+    const char* expr1, const char* expr2
+        , const Elem* val1, const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
     return CmpHelperSTRCASEEQ(expr1, expr2, val1, val2.c_str());
 }
 template<typename Elem, typename Traits, typename Ax>
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(const char* expr1, const char* expr2
-    , const ::std::basic_string<Elem, Traits, Ax>& val1, const Elem* val2)
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(
+    const char* expr1, const char* expr2
+        , const ::std::basic_string<Elem, Traits, Ax>& val1, const Elem* val2)
 {
     return CmpHelperSTRCASEEQ(expr1, expr2, val1.c_str(), val2);
 }
@@ -1103,8 +1172,8 @@ inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const T1& val1, const T2& val2)
 
 template<typename T1, typename T2>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ Assertion(
-      const char* expr1, const char* expr2
-    , const T1& val1, const T2& val2)
+    const char* expr1, const char* expr2
+        , const T1& val1, const T2& val2)
 {
     if( Compare(val1, val2) )
     {
@@ -1119,75 +1188,42 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ Assertion(
 }   // end of namespace StrCaseNeHelper
 
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(
-      const char* expr1, const char* expr2
-    , const char* val1, const char* val2)
+    const char* expr1, const char* expr2
+        , const char* val1, const char* val2)
 {
     return StrCaseNeHelper::Assertion(expr1, expr2, val1, val2);
 }
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(
-      const char* expr1, const char* expr2
-    , const wchar_t* val1, const wchar_t* val2)
+    const char* expr1, const char* expr2
+        , const wchar_t* val1, const wchar_t* val2)
 {
     return StrCaseNeHelper::Assertion(expr1, expr2, val1, val2);
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(
-      const char* expr1, const char* expr2
-    , const ::std::basic_string<Elem, Traits, Ax>& val1
-    , const ::std::basic_string<Elem, Traits, Ax>& val2)
+    const char* expr1, const char* expr2
+        , const ::std::basic_string<Elem, Traits, Ax>& val1
+        , const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
     return CmpHelperSTRCASENE(expr1, expr2, val1.c_str(), val2.c_str());
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(
-      const char* expr1, const char* expr2
-    , const Elem* val1
-    , const ::std::basic_string<Elem, Traits, Ax>& val2)
+    const char* expr1, const char* expr2
+        , const Elem* val1
+        , const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
     return CmpHelperSTRCASENE(expr1, expr2, val1, val2.c_str());
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(
-      const char* expr1, const char* expr2
-    , const ::std::basic_string<Elem, Traits, Ax>& val1
-    , const Elem* val2)
+    const char* expr1, const char* expr2
+        , const ::std::basic_string<Elem, Traits, Ax>& val1
+        , const Elem* val2)
 {
     return CmpHelperSTRCASENE(expr1, expr2, val1.c_str(), val2);
 }
 
-
-template<typename RawType>
-static AssertionResult CmpHelperFloatingPointEQ(const char* expr1, const char* expr2
-                                                , RawType val1, RawType val2)
-{
-    floating_point<RawType> f1(val1), f2(val2);
-    if( f1.AlmostEquals(f2) )
-    {
-        return AssertionSuccess();
-    }
-    return EqFailure(expr1, expr2
-        , detail::ShowStringQuoted(FormatForComparisonFailureMessage(f1, f2))
-        , detail::ShowStringQuoted(FormatForComparisonFailureMessage(f2, f1)));
-}
-
-template<typename RawType>
-static AssertionResult CmpHelperFloatingPointLE(const char* expr1, const char* expr2
-                                                , RawType val1, RawType val2)
-{
-    if( val1 < val2 )
-    {
-        return AssertionSuccess();
-    }
-    floating_point<RawType> f1(val1), f2(val2);
-    if( f1.AlmostEquals(f2) )
-    {
-        return AssertionSuccess();
-    }
-    return EqFailure(expr1, expr2
-        , detail::ShowStringQuoted(FormatForComparisonFailureMessage(f1, f2))
-        , detail::ShowStringQuoted(FormatForComparisonFailureMessage(f2, f1)));
-}
-
 #if defined(IUTEST_OS_WINDOWS)
 
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ IsHRESULTSuccess(const char* expr, HRESULT hr)
@@ -1217,8 +1253,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ IsHRESULTFailure(const char* exp
  * @brief   Float LE Formatter
  * @note    IUTEST_ASSERT_PRED_FORMAT2(::iutest::FloatLE , 0, 1);
 */
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ FloatLE(const char* expr1, const char* expr2
-    , float val1, float val2)
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ FloatLE(
+    const char* expr1, const char* expr2
+        , float val1, float val2)
 {
     return internal::CmpHelperFloatingPointLE<float>(expr1, expr2, val1, val2);
 }
@@ -1227,8 +1264,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ FloatLE(const char* expr1, const
  * @brief   Double LE Formatter
  * @note    IUTEST_ASSERT_PRED_FORMAT2(::iutest::DoubleLE , 0, 1);
 */
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ DoubleLE(const char* expr1, const char* expr2
-    , double val1, double val2)
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ DoubleLE(
+    const char* expr1, const char* expr2
+        , double val1, double val2)
 {
     return internal::CmpHelperFloatingPointLE<double>(expr1, expr2, val1, val2);
 }
